@@ -533,37 +533,37 @@ mcmctsir <- function(data, xreg = 'cumcases',
   contact <- head(contact,52/IP)
 
   ## est initial conditions using determinsitic skeleton
-  
+
   S <- rep(0,length(data$cases))
   I <- rep(0,length(data$cases))
-  
+
   nsample <- 30
-  
+
   inits.grid <- expand.grid(
-    S0 = seq(0.01*mean(pop), 0.1*mean(pop), length=nsample), 
+    S0 = seq(0.01*mean(pop), 0.1*mean(pop), length=nsample),
     I0 = seq(0.01*1e-3*mean(pop), 1*1e-3*mean(pop), length=nsample)
   )
-  
+
   if(inits.fit == TRUE){
-    
+
     inits.res <- rep(NA,nsample*nsample)
-    
+
     for(it in 1:nrow(inits.grid)){
       S0 <- inits.grid[it,1]
       I0 <- inits.grid[it,2]
-      
+
       S[1] <- S0
       I[1] <- I0
-      
-      for (t in 2:(nrow(data))){  
-        
+
+      for (t in 2:(nrow(data))){
+
         lambda <- min(S[t-1],unname(beta[period[t-1]] * S[t-1] * (I[t-1])^alpha))
-        
+
         #if(lambda < 1 || is.nan(lambda) == T){lambda <- 0}
         if(is.nan(lambda) == T){lambda <- 0}
-        
-        I[t] <- lambda 
-        
+
+        I[t] <- lambda
+
         if(epidemics == 'cont'){
           I[t] <- I[t]
         }
@@ -575,62 +575,62 @@ mcmctsir <- function(data, xreg = 'cumcases',
         }
         S[t] <- max(S[t-1] + data$births[t-1] - I[t],0)
       }
-      
+
       inits.res[it] <- sum((I - data$cases*adj.rho)^2)
-      
+
     }
-    
+
     inits <- inits.grid[which.min(inits.res),]
-    
+
     inits.grid$S0 <- inits.grid$S0/mean(pop)
     inits.grid$I0 <- inits.grid$I0/mean(pop)
     inits.grid$log10LS <- log10(inits.res)
-    
+
     S_start <- inits[[1]]
     I_start <- inits[[2]]
-    
+
   }else{
-    
+
     S_start <- sbar + Z[1]
     I_start <- adj.rho[1]*datacopy$cases[1]
-    
+
   }
-  
+
   IC <- c(S_start,I_start)
-  
+
   print(c('alpha'=unname(signif(alpha,2)),
           'mean beta'=unname(signif(mean(beta),3)),
           'mean rho' =unname(signif(mean(1/adj.rho),3)),
           'mean sus' =unname(signif(sbar,3)),
           'prop. init. sus.' =unname(signif(S_start/mean(pop),3)),
-          'prop. init. inf.' =unname(signif(I_start/mean(pop),3))    
+          'prop. init. inf.' =unname(signif(I_start/mean(pop),3))
   ))
-  
-  
+
+
   nsim <- nsim
   res <- matrix(0,length(data$cases),nsim)
   for(ct in 1:nsim){
-    
+
     S <- rep(0,length(data$cases))
     I <- rep(0,length(data$cases))
-    
+
     S[1] <- S_start
     I[1] <- I_start
-    
+
     for (t in 2:(nrow(data))){
-      
+
       if(pred == 'step-ahead'){
         I[t] <- adj.rho[t]*data$cases[t]
         }
       if(pred == 'forward'){
         I <- I
       }
-      
+
       lambda <- min(S[t-1],unname(beta[period[t-1]] * S[t-1] * (I[t-1])^alpha))
-      
+
       #if(lambda < 1 || is.nan(lambda) == T){lambda <- 0}
       if(is.nan(lambda) == T){lambda <- 0}
-      
+
       if(method == 'deterministic'){
         I[t] <- lambda * rnorm( n = 1, mean = 1, sd=mul.noise.sd)
         if(I[t] < 0 && lambda >= 0 ){
@@ -647,41 +647,41 @@ mcmctsir <- function(data, xreg = 'cumcases',
         I[t] <- I[t]
       }
       if(epidemics == 'break'){
-        
+
         t0s <- epitimes(data,threshold)$start
         if(t %in% t0s){
           I[t] <- adj.rho[t]*data$cases[t]
         }
       }
       S[t] <- max(S[t-1] + data$births[t-1] - I[t] + rnorm(n=1,mean=0,sd=add.noise.sd),0)
-      
+
       if(S[t] < 0 && (S[t-1] + data$births[t-1] - I[t]) >0 ){
         warning('susceptible overflow  -- reduce additive noise sd')
       }
     }
     res[,ct] <- I / adj.rho
-    
+
   }
-  
+
   res[is.nan(res)] <- 0
   res[res < 1] <- 0
-  
+
   res <- as.data.frame(res)
-  
+
   #res$mean <- apply(res, 1, function(row) mean(row[-1],na.rm=T))
   res$mean <- rowMeans(res,na.rm=T)
   res$sd   <- apply(res, 1, function(row) sd(row[-1],na.rm=T))
   res$time <- data$time
   res$cases <- data$cases
-  
+
   obs <- res$cases
   pred <- res$mean
-  
+
   fit <- lm(pred ~ obs)
-  
+
   rsquared <- signif(summary(fit)$adj.r.squared, 2)
 
-  return(list('X'=X,'Y'=Y,'Yhat' =Yhat,'mcmcsamples'=mcmcsamples,
+  return(list('X'=X,'Y'=Y,'Yhat' =Yhat,'mcmcsamples'=mcmcsamples,'period'=period,'IP'=IP,
               'beta'=contact$beta,'contact'=contact,'rho'=adj.rho,'pop'=pop,
               'Z'=Z,'sbar'=sbar,'sbarlow'=sbarlow,'sbarhigh=sbarhigh',
               'alpha'=alpha,'alphalow'=alphalow,'alphahigh'=alphahigh,
